Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1251)

Unified Diff: webrtc/p2p/base/transportchannelproxy.cc

Issue 1345913004: Replace readable with receiving where receiving means receiving anything (stun ping, response or da… (Closed) Base URL: https://chromium.googlesource.com/external/webrtc@master
Patch Set: Address comments Created 5 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « webrtc/p2p/base/transportchannelproxy.h ('k') | webrtc/p2p/base/turnport_unittest.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: webrtc/p2p/base/transportchannelproxy.cc
diff --git a/webrtc/p2p/base/transportchannelproxy.cc b/webrtc/p2p/base/transportchannelproxy.cc
index f7946dd96f9a2ec4befabf1413e222052a1bdbcd..74d1e1db762c016525ad7f0f22a2c73ea70ef626 100644
--- a/webrtc/p2p/base/transportchannelproxy.cc
+++ b/webrtc/p2p/base/transportchannelproxy.cc
@@ -55,10 +55,10 @@ void TransportChannelProxy::SetImplementation(TransportChannelImpl* impl) {
impl_ = impl;
if (impl_) {
- impl_->SignalReadableState.connect(
- this, &TransportChannelProxy::OnReadableState);
impl_->SignalWritableState.connect(
this, &TransportChannelProxy::OnWritableState);
+ impl_->SignalReceivingState.connect(
+ this, &TransportChannelProxy::OnReceivingState);
impl_->SignalReadPacket.connect(
this, &TransportChannelProxy::OnReadPacket);
impl_->SignalReadyToSend.connect(
@@ -229,18 +229,18 @@ IceRole TransportChannelProxy::GetIceRole() const {
return impl_->GetIceRole();
}
-void TransportChannelProxy::OnReadableState(TransportChannel* channel) {
+void TransportChannelProxy::OnWritableState(TransportChannel* channel) {
ASSERT(rtc::Thread::Current() == worker_thread_);
ASSERT(channel == impl_);
- set_readable(impl_->readable());
- // Note: SignalReadableState fired by set_readable.
+ set_writable(impl_->writable());
+ // Note: SignalWritableState fired by set_writable.
}
-void TransportChannelProxy::OnWritableState(TransportChannel* channel) {
+void TransportChannelProxy::OnReceivingState(TransportChannel* channel) {
ASSERT(rtc::Thread::Current() == worker_thread_);
ASSERT(channel == impl_);
- set_writable(impl_->writable());
- // Note: SignalWritableState fired by set_readable.
+ set_receiving(impl_->receiving());
+ // Note: SignalReceivingState fired by set_receiving.
}
void TransportChannelProxy::OnReadPacket(
@@ -267,9 +267,9 @@ void TransportChannelProxy::OnRouteChange(TransportChannel* channel,
void TransportChannelProxy::OnMessage(rtc::Message* msg) {
ASSERT(rtc::Thread::Current() == worker_thread_);
if (msg->message_id == MSG_UPDATESTATE) {
- // If impl_ is already readable or writable, push up those signals.
- set_readable(impl_ ? impl_->readable() : false);
- set_writable(impl_ ? impl_->writable() : false);
+ // If impl_ is already receiving or writable, push up those signals.
+ set_writable(impl_ ? impl_->writable() : false);
+ set_receiving(impl_ ? impl_->receiving() : false);
}
}
« no previous file with comments | « webrtc/p2p/base/transportchannelproxy.h ('k') | webrtc/p2p/base/turnport_unittest.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698